/*
 * GCLC swt, provide a swt window for console applications
 * Copyright (C) 2015-2017 E. Bigeon
 * mailto:emmanuel@bigeon.fr
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc-swt:fr.bigeon.gclc.swt.SWTConsoleShell.java
 * Created on: Apr 18, 2015
 */
package fr.bigeon.gclc.swt;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;

/** A shell containing a {@link SWTConsole}
 * <p>
 *
 * @author Emmanuel Bigeon */
public final class SWTConsoleShell extends Shell {

    /** The console component */
    private SWTConsole console;

    /** Create the shell.
     *
     * @param display the display */
    public SWTConsoleShell(final Display display) {
        super(display, SWT.SHELL_TRIM);
        setLayout(new FillLayout(SWT.HORIZONTAL));

        createContents();
    }

    @Override
    protected void checkSubclass() {
        // Disable the check that prevents subclassing of SWT components
    }

    /** Create contents of the shell. */
    protected void createContents() {
        console = new SWTConsole(this, SWT.NONE);
        setText("Console Application"); //$NON-NLS-1$
    }

    /* (non-Javadoc)
     * @see org.eclipse.swt.widgets.Shell#dispose() */
    @Override
    public void dispose() {
        super.dispose();
        console.close();
    }

    /** @return the input and output. */
    public SWTConsole getManager() {
        return console;
    }
}
